@@ -26,6 +26,7 @@ from cpg_utils.workflows.utils import exists
 from cpg_utils.workflows.filetypes import (
     FastqPair,
     CramPath,
+    BamPath,
     AlignmentInput,
     FastqPairs,
 )
@@ -178,9 +179,12 @@ class Metamist:
         """
         Query the DB to find the last completed joint-calling analysis for the samples.
         """
+        project = dataset or self.default_dataset
+        if get_config()['workflow']['access_level'] == 'test':
+            project += '-test'
         try:
             data = self.aapi.get_latest_complete_analysis_for_type(
-                project=dataset or self.default_dataset,
+                project=project,
                 analysis_type=models.AnalysisType('joint-calling'),
             )
         except ApiException:
@@ -208,15 +212,16 @@ class Metamist:
         sample (e.g. cram, gvcf).
         """
         dataset = dataset or self.default_dataset
+        project = dataset or self.default_dataset
+        if get_config()['workflow']['access_level'] == 'test':
+            project += '-test'
 
         analysis_per_sid: dict[str, Analysis] = dict()
 
-        logging.info(
-            f'Querying {analysis_type} analysis entries for dataset {dataset}...'
-        )
+        logging.info(f'Querying {analysis_type} analysis entries for {project}...')
         datas = self.aapi.query_analyses(
             models.AnalysisQueryModel(
-                projects=[dataset],
+                projects=[project],
                 sample_ids=sample_ids,
                 type=models.AnalysisType(analysis_type.value),
                 status=models.AnalysisStatus(analysis_status.value),
@@ -233,7 +238,7 @@ class Metamist:
             assert len(a.sample_ids) == 1, data
             analysis_per_sid[list(a.sample_ids)[0]] = a
         logging.info(
-            f'Querying {analysis_type} analysis entries for dataset {dataset}: '
+            f'Querying {analysis_type} analysis entries for {project}: '
             f'found {len(analysis_per_sid)}'
         )
         return analysis_per_sid
@@ -251,6 +256,9 @@ class Metamist:
         Tries to create an Analysis entry, returns its id if successful.
         """
         dataset = dataset or self.default_dataset
+        project = dataset or self.default_dataset
+        if get_config()['workflow']['access_level'] == 'test':
+            project += '-test'
 
         if isinstance(type_, AnalysisType):
             type_ = type_.value
@@ -265,14 +273,14 @@ class Metamist:
             meta=meta or {},
         )
         try:
-            aid = self.aapi.create_new_analysis(project=dataset, analysis_model=am)
+            aid = self.aapi.create_new_analysis(project=project, analysis_model=am)
         except ApiException:
             traceback.print_exc()
             return None
         else:
             logging.info(
                 f'Created Analysis(id={aid}, type={type_}, status={status}, '
-                f'output={str(output)}) in project {dataset}'
+                f'output={str(output)}) in {project}'
             )
             return aid
 
@@ -297,7 +305,7 @@ class Metamist:
         @param analysis_type: cram, gvcf, joint_calling
         @param expected_output_fpath: where the workflow expects the analysis output
         file to sit on the bucket (will invalidate the analysis when it doesn't match)
-        @param dataset: the name of the project where to create a new analysis
+        @param dataset: the name of the dataset to create a new analysis
         @return: path to the output if it can be reused, otherwise None
         """
         label = f'type={analysis_type}'
@@ -472,42 +480,54 @@ class Sequence:
                 logging.error(f'{sample_id}: supporting only single bam/cram input')
                 return None
 
-            bam_path = reads_data[0]['location']
-            if not (bam_path.endswith('.cram') or bam_path.endswith('.bam')):
+            location = reads_data[0]['location']
+            if not (location.endswith('.cram') or location.endswith('.bam')):
                 logging.error(
                     f'{sample_id}: ERROR: expected the file to have an extension '
-                    f'.cram or .bam, got: {bam_path}'
+                    f'.cram or .bam, got: {location}'
                 )
                 return None
-            if check_existence and not exists(bam_path):
+            if get_config()['workflow']['access_level'] == 'test':
+                location = location.replace('-main-upload/', '-test-upload/')
+            if check_existence and not exists(location):
                 logging.error(
-                    f'{sample_id}: ERROR: index file does not exist: {bam_path}'
+                    f'{sample_id}: ERROR: index file does not exist: {location}'
                 )
                 return None
 
             # Index:
-            index_path = None
+            index_location = None
             if reads_data[0].get('secondaryFiles'):
-                index_path = reads_data[0]['secondaryFiles'][0]['location']
+                index_location = reads_data[0]['secondaryFiles'][0]['location']
                 if (
-                    bam_path.endswith('.cram')
-                    and not index_path.endswith('.crai')
-                    or bam_path.endswith('.bai')
-                    and not index_path.endswith('.bai')
+                    location.endswith('.cram')
+                    and not index_location.endswith('.crai')
+                    or location.endswith('.bai')
+                    and not index_location.endswith('.bai')
                 ):
                     logging.error(
                         f'{sample_id}: ERROR: expected the index file to have an extension '
-                        f'.crai or .bai, got: {index_path}'
+                        f'.crai or .bai, got: {index_location}'
                     )
-                if check_existence and not exists(index_path):
+                if get_config()['workflow']['access_level'] == 'test':
+                    index_location = index_location.replace(
+                        '-main-upload/', '-test-upload/'
+                    )
+                if check_existence and not exists(index_location):
                     logging.error(
-                        f'{sample_id}: ERROR: index file does not exist: {index_path}'
+                        f'{sample_id}: ERROR: index file does not exist: {index_location}'
                     )
                     return None
 
-            return CramPath(
-                bam_path, index_path=index_path, reference_assembly=reference_assembly
-            )
+            if location.endswith('.cram'):
+                return CramPath(
+                    location,
+                    index_path=index_location,
+                    reference_assembly=reference_assembly,
+                )
+            else:
+                assert location.endswith('.bam')
+                return BamPath(location, index_path=index_location)
 
         else:
             fastq_pairs = FastqPairs()
@@ -519,6 +539,13 @@ class Sequence:
                         f'but got {len(lane_pair)}. '
                         f'Read data: {pprint.pformat(reads_data)}'
                     )
+                if get_config()['workflow']['access_level'] == 'test':
+                    lane_pair[0]['location'] = lane_pair[0]['location'].replace(
+                        '-main-upload/', '-test-upload/'
+                    )
+                    lane_pair[1]['location'] = lane_pair[1]['location'].replace(
+                        '-main-upload/', '-test-upload/'
+                    )
                 if check_existence and not exists(lane_pair[0]['location']):
                     logging.error(
                         f'{sample_id}: ERROR: read 1 file does not exist: '
